@@ -9,14 +9,15 @@
 #           + expected format: "{0..59} {0..23} {*|SUN|MON|TUE|WED|THU|FRI|SAT}"
 #           + "" (empty string) to disable the check or email setting.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import sys
 from dgpy.cms_client              import CmsClient
 from dgpy.safehaven.cron.cron_pb2 import ClusterMonitorSpec
 from dgpy.errors                  import GrpcError
 
 if len(sys.argv) != 3 or sys.argv[1] not in ('check', 'email'):
-    print >>sys.stderr, 'Usage:   %s check|email <spec>' % sys.argv[0]
-    print >>sys.stderr, 'Example: %s check "0 12 THU"' % sys.argv[0]
+    print('Usage:   %s check|email <spec>' % sys.argv[0], file=sys.stderr)
+    print('Example: %s check "0 12 THU"' % sys.argv[0], file=sys.stderr)
 else:
     try:
         spec = ClusterMonitorSpec()
@@ -28,6 +29,6 @@ else:
             spec.report_email_repeat = sys.argv[2]
         res = CmsClient().cluster_monitor_set_cron(spec)
     except GrpcError as e:
-        print "Failed to configure cluster monitor crontab entries: {0}".format(e)
+        print("Failed to configure cluster monitor crontab entries: {0}".format(e))
     else:
-        print "Configure cluster crontab entries Job ID: {0}".format(res.job_id)
+        print("Configure cluster crontab entries Job ID: {0}".format(res.job_id))
