@@ -2,6 +2,7 @@
 #
 # Stops the safehaven-service on the given SRN.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
@@ -22,7 +23,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Stop SRN {0} safehaven-service job #{1}".format(args.SRN_IP, res.job_id)
+        print("Stop SRN {0} safehaven-service job #{1}".format(args.SRN_IP, res.job_id))
 except LegacyMessageError as e:
     die("Failed to stop the service on {0}: {1}".format(args.SRN_IP, e))
 except TimeOutError as e:
