@@ -2,11 +2,12 @@
 #
 # Delete a user from the system.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
 from dgpy.job        import status_printer
-from dgpy.errors     import LegacyMessageError, GrpcError, NotFoundError, TimeOutError
+from dgpy.errors     import LegacyMessageError, GrpcError, TimeOutError
 
 parser = argparse.ArgumentParser(description="Delete @USER from the system")
 
@@ -21,7 +22,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Remove user {0} Job ID: {1}".format(args.USER, res.job_id)
+        print("Remove user {0} Job ID: {1}".format(args.USER, res.job_id))
 except (LegacyMessageError, GrpcError) as e:
     die("Failed to remove {0}: {1}".format(args.USER, e))
 except TimeOutError as e:
